#!/bin/sh

# T2C_ROOT is not necessary to run the tests

# Get the directory where this script resides.
WORK_DIR=$(cd `dirname $0` && pwd) 
T2C_SUITE_ROOT=${WORK_DIR}
export T2C_SUITE_ROOT

cd ${T2C_SUITE_ROOT}

if [ -z ${TET_ROOT} ]
then
    TET_ROOT=/opt/lsb-tet3-lite
fi

echo TET_ROOT is ${TET_ROOT}
#echo T2C_SUITE_ROOT is ${T2C_SUITE_ROOT}

export TET_ROOT
export TET_PATH=$TET_ROOT
export PATH=/opt/lsb/bin:$PATH:$TET_PATH/bin:/sbin
export TET_SUITE_ROOT=`pwd`

export CC=lsbcc
for x in /opt/lsb/lib*/pkgconfig; do
    PKG_CONFIG_PATH="${x}${PKG_CONFIG_PATH+:${PKG_CONFIG_PATH}}"
done
export PKG_CONFIG_PATH

if [ "$1" = "-noxvfb" ]; then
	USE_XVFB=
	shift
else
	USE_XVFB=yes
fi

XT_DISPLAYHOST=localhost
XT_FONTPATH=/opt/lsb/share/fonts/misc/ 

# Find a free display to use for Xvfb

DISPLAY_NUM=9    #default display number
which xprop > /dev/null 2>&1
if [ $? -eq 0 ]; then
    #OK, found xprop, now use it to get a free display number

    DNUM_LIST="9 8 7 6 5 4 3 2 10 11 12" #try these display numbers only
    
    for DNUM in `echo ${DNUM_LIST}`; do
	xprop -display :${DNUM}.0 -root >/dev/null 2>&1
	if [ $? -ne 0 ]; then
	    # no properties found for this display, guess it is free
	    DISPLAY_NUM=${DNUM}
	    break
	fi
    done
    
fi

XT_DISPLAY=":${DISPLAY_NUM}.0"
TEST_DISPLAY=${XT_DISPLAY}
echo "Display ${TEST_DISPLAY} is free."

XVFB_RUNNING=""
#---------------------------------------------------------
# start xvfb if it isn't already running
startXvfb()
{
    running=`pidof Xvfb`
	XVFB_RUNNING=running
    if [ -z "${running}" ];then
        /opt/lsb/bin/Xvfb -render -screen 0 1024x768x24 $TEST_DISPLAY -ac +bs -kb -fp $XT_FONTPATH >/dev/null 2>&1 &
        echo "Starting X Virtual Frame Buffer"; sleep 20
        export DISPLAY=${TEST_DISPLAY}
	else
		#Xvfb is running, determine the display number
		CMD_XVFB=`ps -p "${running}" -f | tail -n 1`
		XT_DISPLAY=`echo $CMD_XVFB | sed 's/.*\(:[0-9]*\.0\).*/\1/'`
		export DISPLAY=${XT_DISPLAY}
		
		echo "Xvfb is already running (display: ${DISPLAY}), so it will be used."
    fi

}

stopXvfb()
{
	if [ -z "${XVFB_RUNNING}" ]; then
    	running=`pidof Xvfb`
	else
		running=""
	fi

    if [ -n "$running" ];then
        kill $running
    fi
}

if [ ! -z "${USE_XVFB}" ]; then
	startXvfb
fi
 
#---------------------------------------------------------
#remove previous results and temporaries
rm -rf results
rm -rf tet_tmp_dir

#run the tests

if [ -z $1 ]
then
    tcc -e .
    
else
    #save old tet_scen
    mv -f tet_scen tet_scen.orig
    
    echo "all" >> tet_scen

    cat tet_scen.orig | grep $1 >> tet_scen
	if [ $? != 0 ] 
	then 
		echo Test suite is not found: $1.
	else
    	tcc -e . 
	fi
    
    #restore old tet_scen
    mv -f tet_scen.orig tet_scen
fi 

if [ ! -z "${USE_XVFB}" ]; then
	stopXvfb
fi

#remove temporaries
rm -rf tet_tmp_dir

exit 0
